@@ -3,7 +3,7 @@
 from logging import basicConfig
 from random import shuffle
 
-from homeinfotools.functions import get_log_level, handle_keyboard_interrupt
+from homeinfotools.functions import get_log_level
 from homeinfotools.logging import LOG_FORMAT
 from homeinfotools.multiprocessing import multiprocess
 from homeinfotools.filetransfer.argparse import get_args
@@ -13,8 +13,7 @@ from homeinfotools.filetransfer.worker import Worker
 __all__ = ['main']
 
 
-@handle_keyboard_interrupt
-def main() -> None:
+def main() -> int:
     """Runs the script."""
 
     args = get_args()
@@ -23,4 +22,9 @@ def main() -> None:
     if args.shuffle:
         shuffle(args.systems)
 
-    multiprocess(Worker, args.system, args.processes, args=args)
+    try:
+        multiprocess(Worker, args.system, args.processes, args=args)
+    except KeyboardInterrupt:
+        return 1
+
+    return 0
