@@ -2,7 +2,7 @@
 
 from getpass import getpass
 from sys import exit    # pylint: disable=W0622
-from typing import Tuple
+from typing import Optional
 
 from homeinfotools.logging import LOGGER
 
@@ -10,7 +10,8 @@ from homeinfotools.logging import LOGGER
 __all__ = ['update_credentials']
 
 
-def update_credentials(account: str, passwd: str = None) -> Tuple[str, str]:
+def update_credentials(account: Optional[str],
+                       passwd: Optional[str] = None) -> tuple[str, str]:
     """Reads the credentials for a HIS account."""
 
     if not account:
