@@ -2,8 +2,9 @@
 
 from json import dump
 from logging import basicConfig
+from random import shuffle
 
-from homeinfotools.functions import get_log_level, handle_keyboard_interrupt
+from homeinfotools.functions import get_log_level
 from homeinfotools.logging import LOG_FORMAT
 from homeinfotools.multiprocessing import multiprocess
 from homeinfotools.rpc.argparse import get_args
@@ -13,14 +14,22 @@ from homeinfotools.rpc.worker import Worker
 __all__ = ['main']
 
 
-@handle_keyboard_interrupt
-def main() -> None:
+def main() -> int:
     """Runs the script."""
 
     args = get_args()
     basicConfig(format=LOG_FORMAT, level=get_log_level(args))
-    result = multiprocess(Worker, args.system, args.processes, args=args)
+
+    if args.shuffle:
+        shuffle(args.systems)
+
+    try:
+        result = multiprocess(Worker, args.system, args.processes, args=args)
+    except KeyboardInterrupt:
+        return 1
 
     if args.json is not None:
         with args.json.open('w') as file:
             dump(dict(result), file, indent=2)
+
+    return 0
